@@ -2,3 +2,5 @@ pub mod tag;
 pub mod client;
 pub mod common;
 pub mod gc;
+pub mod user;
+pub mod project;
